package cn.kdan.pdf.backend.core.service;

import cn.kdan.pdf.backend.core.model.Members;
import cn.kdan.pdf.backend.core.model.member.MemberInfoResp;
import cn.kdan.pdf.backend.core.model.member.MemberRegisterReq;
import cn.kdan.pdf.backend.core.model.member.MemberRegisterResp;
import cn.kdan.pdf.backend.core.model.member.ModifyPasswordReq;
import cn.kdan.pdf.backend.core.params.UserResetPwdParams;

public interface MemberService {

    /**
     * 用户注册
     *
     * @param req 注册参数
     * @return 注册回参
     */
    MemberRegisterResp register(MemberRegisterReq req);

    /**
     * 修改密码
     *
     * @param req 修改密码请求参数
     */
    void modifyPassword(ModifyPasswordReq req);

    /**
     * 修改昵称
     *
     * @param name 修改昵称请求参数
     */
    void modifyNickname(String name);

    /**
     * 获取用户信息
     *
     * @param id 用户id，无id就传null
     * @return 用户信息
     */
    MemberInfoResp getMemberDetail(String id);

    /**
     * 获取当前用户
     *
     * @return Members
     */
    Members getCurrentUser();

    /**
     * 根据id查询用户
     *
     * @param memberId 用户id
     * @return Members
     */
    Members getById(String memberId);

    /**
     * 重置密码
     *
     * @param params UserResetPwdParams
     * @return boolean
     */
    boolean resetPassword(UserResetPwdParams params);

    /**
     * 更新用户
     *
     * @param member 用户
     */
    void update(Members member);

    /**
     * 根据用户名查询用户
     * @param name 昵称
     * @return 用户信息
     */
    Members selectByName(String name);

    /**
     * 注销账号
     * @return 用户id
     */
    String cancelAccount();

}
